@@ -37,6 +37,20 @@ function(libname, pkgname)
 }
 
 
+
+.Call =
+function(name, ...)
+{
+  base::.Call(name, ..., PACKAGE = "XML")
+}
+
+.C =
+function(name, ...)
+{
+  base::.C(name, ..., PACKAGE = "XML")
+}
+
+
 #
 #  Copyright (c) 1998, 1999 The Omega Project for Statistical Computing.
 #       All rights reserved.#
